==> xoonips-3.48.zip: xoonips-3.48/itemtypes/xnpfiles/language/japanese/main.php <==
<?php
// $Revision: 1.1.12.5 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2013 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.12.5 $
 */

// _MD_<MODULENAME>_<STRINGNAME>

define( "_MD_XNPFILES_DATE_LABEL", "" );
define( "_MD_XNPFILES_DATA_FILE_LABEL", "ե" );
define( "_MD_XNPFILES_DATA_FILE_NAME", "- ե̾" );
define( "_MD_XNPFILES_DATA_FILE_MIMETYPE", "- MIME" );
define( "_MD_XNPFILES_DATA_FILE_FILETYPE", "- ե륿" );
define( "_MD_XNPFILES_DATA_FILE_REQUIRED", "'ǡե' ϤƲ" );
define( '_MD_XNPFILES_EXPLANATION' , "ե" );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_ID'           , 'ƥID' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_NAME'     , 'ե̾' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_MIMETYPE' , 'MIME' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_FILETYPE' , 'ե륿' );
define( '_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_FILE'         , 'ե' );

==> xoonips-3.50.zip: xoonips-3.50/itemtypes/xnpfiles/language/japanese/main.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2013 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 */

// _MD_<MODULENAME>_<STRINGNAME>

define('_MD_XNPFILES_DATE_LABEL', '');
define('_MD_XNPFILES_DATA_FILE_LABEL', 'ե');
define('_MD_XNPFILES_DATA_FILE_NAME', '- ե̾');
define('_MD_XNPFILES_DATA_FILE_MIMETYPE', '- MIME');
define('_MD_XNPFILES_DATA_FILE_FILETYPE', '- ե륿');
define('_MD_XNPFILES_DATA_FILE_REQUIRED', "'ǡե' ϤƲ");
define('_MD_XNPFILES_EXPLANATION', 'ե');
define('_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_ID', 'ƥID');
define('_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_NAME', 'ե̾');
define('_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_MIMETYPE', 'MIME');
define('_MD_XNPFILES_XMLRPC_DISPLAY_NAME_DATA_FILE_FILETYPE', 'ե륿');
define('_MD_XNPFILES_XMLRPC_DISPLAY_NAME_FILES_FILE', 'ե');
